@@ -542,87 +542,6 @@ class CreateCRDesktopCodeResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class CreateCRObtainRequest(AbstractModel):
-    """CreateCRObtain请求参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param WorkId: 已存证的作品ID
-        :type WorkId: int
-        :param TortUrl: 侵权链接
-        :type TortUrl: str
-        :param ObtainType: 取证类型 1-网页取证 2-过程取证
-        :type ObtainType: int
-        :param WorkTitle: 侵权标题
-        :type WorkTitle: str
-        :param TortPlat: 侵权平台
-        :type TortPlat: str
-        :param ObtainDuration: 过程取证的取证时长 6-300分钟
-        :type ObtainDuration: int
-        :param ObtainUrl: 取证回调地址
-        :type ObtainUrl: str
-        :param WorkCategory: xxx
-        :type WorkCategory: str
-        :param WorkType: xxx
-        :type WorkType: str
-        """
-        self.WorkId = None
-        self.TortUrl = None
-        self.ObtainType = None
-        self.WorkTitle = None
-        self.TortPlat = None
-        self.ObtainDuration = None
-        self.ObtainUrl = None
-        self.WorkCategory = None
-        self.WorkType = None
-
-
-    def _deserialize(self, params):
-        self.WorkId = params.get("WorkId")
-        self.TortUrl = params.get("TortUrl")
-        self.ObtainType = params.get("ObtainType")
-        self.WorkTitle = params.get("WorkTitle")
-        self.TortPlat = params.get("TortPlat")
-        self.ObtainDuration = params.get("ObtainDuration")
-        self.ObtainUrl = params.get("ObtainUrl")
-        self.WorkCategory = params.get("WorkCategory")
-        self.WorkType = params.get("WorkType")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class CreateCRObtainResponse(AbstractModel):
-    """CreateCRObtain返回参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param TortId: 侵权ID
-        :type TortId: int
-        :param TortNum: xxx
-        :type TortNum: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
-        self.TortId = None
-        self.TortNum = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        self.TortId = params.get("TortId")
-        self.TortNum = params.get("TortNum")
-        self.RequestId = params.get("RequestId")
-
-
 class CreateCRRightFileRequest(AbstractModel):
     """CreateCRRightFile请求参数结构体
 
@@ -1009,6 +928,8 @@ class CreateCRWorkRequest(AbstractModel):
         :type ApplierId: str
         :param ApplierName: 申请人姓名，用于存证和取证
         :type ApplierName: str
+        :param IsAutoRenew: 是否自动续期
+        :type IsAutoRenew: str
         """
         self.WorkName = None
         self.WorkCategory = None
@@ -1041,6 +962,7 @@ class CreateCRWorkRequest(AbstractModel):
         self.MonitorEndTime = None
         self.ApplierId = None
         self.ApplierName = None
+        self.IsAutoRenew = None
 
 
     def _deserialize(self, params):
@@ -1075,6 +997,7 @@ class CreateCRWorkRequest(AbstractModel):
         self.MonitorEndTime = params.get("MonitorEndTime")
         self.ApplierId = params.get("ApplierId")
         self.ApplierName = params.get("ApplierName")
+        self.IsAutoRenew = params.get("IsAutoRenew")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2232,6 +2155,10 @@ class Monitor(AbstractModel):
         :type EvidenceNote: str
         :param TortSiteNum: 侵权站点数量
         :type TortSiteNum: int
+        :param MonitorEndTime: 监测截止时间
+        :type MonitorEndTime: str
+        :param AutoRenew: 是否自动续费
+        :type AutoRenew: int
         """
         self.WorkId = None
         self.WorkName = None
@@ -2247,6 +2174,8 @@ class Monitor(AbstractModel):
         self.EvidenceStatus = None
         self.EvidenceNote = None
         self.TortSiteNum = None
+        self.MonitorEndTime = None
+        self.AutoRenew = None
 
 
     def _deserialize(self, params):
@@ -2264,6 +2193,8 @@ class Monitor(AbstractModel):
         self.EvidenceStatus = params.get("EvidenceStatus")
         self.EvidenceNote = params.get("EvidenceNote")
         self.TortSiteNum = params.get("TortSiteNum")
+        self.MonitorEndTime = params.get("MonitorEndTime")
+        self.AutoRenew = params.get("AutoRenew")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
